@@ -1,3 +1,29 @@
+//! # Overview
+//!
+//! A high-level Rust wrapper API for [fetisov's ttf2mesh](https://github.com/fetisov/ttf2mesh/)
+//! library for generating a 2d/3d mesh (vertices, indices and normals [only for 3D])
+//! from TrueType (`.ttf`) glyphs.
+//!
+//! Usage:
+//! ```rust
+//! # use ttf2mesh::{TTFFile, Quality};
+//! #
+//! let mut ttf = TTFFile::from_file("./fonts/FiraMono-Medium.ttf").unwrap();
+//!
+//! // export all glyphs as 2d meshes to a .obj file
+//! ttf.export_to_obj("/dev/null", Quality::Low).unwrap();
+//!
+//! // generate 2d mesh for a glyph
+//! let mut glyph = ttf.glyph_from_char('€').unwrap();
+//! let mesh = glyph.to_2d_mesh(Quality::Medium).unwrap();
+//!
+//! // work with Mesh vertices, faces (indices). See Mesh documentation for more
+//! assert_eq!(mesh.vertices_len(), 56);
+//! assert_eq!(mesh.iter_vertices().next().unwrap().val(), (0.555, 0.656));
+//!
+//! assert_eq!(mesh.faces_len(), 54);
+//! assert_eq!(mesh.iter_faces().next().unwrap().val(), (53, 52, 5));
+//! ```
 #![feature(test)]
 extern crate test;
 
@@ -6,7 +32,7 @@ use std::{ffi::CString, os::unix::prelude::OsStrExt, path::Path};
 mod error;
 mod glyph;
 mod mesh;
-mod outputs;
+pub mod output;
 mod quality;
 mod ttf;
 
@@ -55,16 +81,16 @@ mod tests {
     }
 
     #[test]
-    fn test_get_glyph_by_char() {
+    fn test_get_glyph_from_char() {
         let mut font = TTFFile::from_buffer_vec(read_font(None)).unwrap();
         let char = "A".chars().next().unwrap();
-        let _ = font.glyph_by_char(char).unwrap();
+        let _ = font.glyph_from_char(char).unwrap();
     }
 
     #[test]
     fn test_to_3d_mesh() {
         let mut font = TTFFile::from_buffer_vec(read_font(None)).unwrap();
-        let mut glyph = font.glyph_by_char("€".chars().next().unwrap()).unwrap();
+        let mut glyph = font.glyph_from_char("€".chars().next().unwrap()).unwrap();
         let mesh = glyph.to_3d_mesh(Quality::Low, 0.5).unwrap();
 
         let mut sizes = Vec::new();
@@ -96,7 +122,7 @@ mod tests {
     #[test]
     fn test_to_2d_mesh() {
         let mut font = TTFFile::from_buffer_vec(read_font(None)).unwrap();
-        let mut glyph = font.glyph_by_char("€".chars().next().unwrap()).unwrap();
+        let mut glyph = font.glyph_from_char("€".chars().next().unwrap()).unwrap();
 
         let mut sizes = Vec::new();
         let mesh = glyph.to_2d_mesh(Quality::Low).unwrap();
@@ -136,7 +162,7 @@ mod tests {
         let char = "€".chars().next().unwrap();
 
         b.iter(|| {
-            let _ = font.glyph_by_char(char).unwrap();
+            let _ = font.glyph_from_char(char).unwrap();
         });
     }
 
@@ -145,7 +171,7 @@ mod tests {
         let mut font = TTFFile::from_buffer_vec(read_font(None)).unwrap();
 
         let char = "€".chars().next().unwrap();
-        let mut glyph = font.glyph_by_char(char).unwrap();
+        let mut glyph = font.glyph_from_char(char).unwrap();
 
         b.iter(|| {
             let _ = glyph.to_3d_mesh(Quality::Low, 0.1).unwrap();
@@ -157,7 +183,7 @@ mod tests {
         let mut font = TTFFile::from_buffer_vec(read_font(None)).unwrap();
 
         let char = "€".chars().next().unwrap();
-        let mut glyph = font.glyph_by_char(char).unwrap();
+        let mut glyph = font.glyph_from_char(char).unwrap();
 
         b.iter(|| {
             let _ = glyph.to_3d_mesh(Quality::High, 0.1).unwrap();
@@ -169,7 +195,7 @@ mod tests {
         let mut font = TTFFile::from_buffer_vec(read_font(None)).unwrap();
 
         let char = "€".chars().next().unwrap();
-        let mut glyph = font.glyph_by_char(char).unwrap();
+        let mut glyph = font.glyph_from_char(char).unwrap();
 
         b.iter(|| {
             let _ = glyph.to_2d_mesh(Quality::Low).unwrap();
@@ -181,7 +207,7 @@ mod tests {
         let mut font = TTFFile::from_buffer_vec(read_font(None)).unwrap();
 
         let char = "€".chars().next().unwrap();
-        let mut glyph = font.glyph_by_char(char).unwrap();
+        let mut glyph = font.glyph_from_char(char).unwrap();
 
         b.iter(|| {
             let _ = glyph.to_2d_mesh(Quality::High).unwrap();
